summaryrefslogtreecommitdiffstats
path: root/kdat/BackupDlg.h
diff options
context:
space:
mode:
Diffstat (limited to 'kdat/BackupDlg.h')
-rw-r--r--kdat/BackupDlg.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kdat/BackupDlg.h b/kdat/BackupDlg.h
index 0cbc61c..d98d91c 100644
--- a/kdat/BackupDlg.h
+++ b/kdat/BackupDlg.h
@@ -93,12 +93,12 @@ public:
* @param removeSnapshot Remove the snapshot before backing up.
* @param archiveSize The estimate size of the archive in kilobytes.
* @param tape The tape index to add the archive to.
* @param tqparent The tqparent widget for this dialog.
* @param name The name of this widget.
*/
BackupDlg( const TQString & archiveName, const TQString & workingDir, const TQStringList& files, bool oneFilesystem, bool incremental,
const TQString & snapshot, bool removeSnapshot, int archiveSize, Tape* tape,
- TQWidget* tqparent = 0, const char* name = 0 );
+ TQWidget* parent = 0, const char* name = 0 );
/**
* Destroy the backup dialog.
@@ -93,12 +93,12 @@ public:
* @param archiveSize The estimate size of the archive in kilobytes.
* @param tape The tape index to add the archive to.
- * @param tqparent The tqparent widget for this dialog.
+ * @param parent The parent widget for this dialog.
* @param name The name of this widget.
*/